==> bluebonnet-0.1.0.tar.gz: bluebonnet-0.1.0/tests/fluids/test_oil.py <==
"""Define a suite a tests for the oil module."""
from __future__ import annotations

import math

import pytest

from bluebonnet.fluids import oil

TEMPERATURE_STANDARD = 60.0
PRESSURE_STANDARD = 14.70


def test_bubblepoint_pressure_Standing(oil_properties):
    """Test Standing bubblepoint pressure calculation."""
    (
        temperature,
        pressure,
        api_gravity,
        gas_specific_gravity,
        solution_gor_initial,
        fluid,
    ) = oil_properties
    pressure_bubblepoint_real = pytest.approx(2603.1217021875277)
    pressure_bubblepoint = oil.pressure_bubblepoint_Standing(
        temperature, api_gravity, gas_specific_gravity, solution_gor_initial
    )
    assert pressure_bubblepoint == pressure_bubblepoint_real


def test_solution_gor_Standing(oil_properties):
    """Test Standing calculation of solution gas:oil raio."""
    (
        temperature,
        pressure,
        api_gravity,
        gas_specific_gravity,
        solution_gor_initial,
        fluid,
    ) = oil_properties
    if fluid == "black oil" and math.fabs(pressure - 3000) < 1:
        gor_real = pytest.approx(650)
    elif fluid == "black oil" and math.fabs(pressure - 2000) < 1:
        gor_real = pytest.approx(474.8228813376839)
    else:
        raise NotImplementedError
    gor_standing = oil.solution_gor_Standing(
        temperature, pressure, api_gravity, gas_specific_gravity, solution_gor_initial
    )
    assert gor_standing == gor_real


def test_dgor_dpressure_Standing(oil_properties):
    """Test whether Standing gets change in GOR over pressure right."""
    (
        temperature,
        pressure,
        api_gravity,
        gas_specific_gravity,
        solution_gor_initial,
        fluid,
    ) = oil_properties
    if fluid == "black oil" and math.fabs(pressure - 3000) < 1:
        dgor_real = pytest.approx(0)
    elif fluid == "black oil" and math.fabs(pressure - 2000) < 1:
        dgor_real = pytest.approx(0.2824395998221715)
    else:
        raise NotImplementedError
    dgor_standing = oil.dgor_dpressure_Standing(
        temperature, pressure, api_gravity, gas_specific_gravity, solution_gor_initial
    )
    assert dgor_standing == dgor_real


def test_B_o_bubblepoint_Standing(oil_properties):
    """Test Standing bubblepoint formation volume factor."""
    (
        temperature,
        pressure,
        api_gravity,
        gas_specific_gravity,
        solution_gor_initial,
        fluid,
    ) = oil_properties
    B_o_bubblepoint_real = pytest.approx(1.3860514623492897)
    B_o_Standing = oil.b_o_bubblepoint_Standing(
        temperature, api_gravity, gas_specific_gravity, solution_gor_initial
    )
    assert B_o_bubblepoint_real == B_o_Standing


def test_oil_compressibility_undersat_Standing(oil_properties):
    """Test Standing oil compressibility for undersaturated oil."""
    (
        temperature,
        pressure,
        api_gravity,
        gas_specific_gravity,
        solution_gor_initial,
        fluid,
    ) = oil_properties

    # overwrite pressure to be above saturation pressure
    pressure = 3000.0
    C_o_real = pytest.approx(1.4719851e-05)
    C_o_Standing = oil.oil_compressibility_undersat_Standing(
        temperature, pressure, api_gravity, gas_specific_gravity, solution_gor_initial
    )
    assert C_o_Standing == C_o_real


def test_oil_compressibility_undersat_Spivey(oil_properties):
    """Test Spivey's oil compressibility for undersaturated oil."""
    (
        temperature,
        pressure,
        api_gravity,
        gas_specific_gravity,
        solution_gor_initial,
        _,
    ) = oil_properties

    # overwrite pressure to be above saturation pressure
    if pressure < 2001.0:
        pytest.skip("only makes sense if undersaturated")
    C_o_real = pytest.approx(9.1723089e-6)
    C_o_Spivey = oil.oil_compressibility_undersat_Spivey(
        temperature, pressure, api_gravity, gas_specific_gravity, solution_gor_initial
    )
    assert C_o_Spivey == C_o_real


def test_B_o_Standing(oil_properties):
    """Test Standing's formation volume factor (all saturations) for oil."""
    (
        temperature,
        pressure,
        api_gravity,
        gas_specific_gravity,
        solution_gor_initial,
        fluid,
    ) = oil_properties
    if fluid == "black oil" and math.fabs(pressure - 3000) < 1:
        B_o_real = pytest.approx(1.38101, rel=1e-3)
    elif fluid == "black oil" and math.fabs(pressure - 2000) < 1:
        B_o_real = pytest.approx(1.2929990, rel=1e-3)
    else:
        raise NotImplementedError
    B_o_Standing = oil.b_o_Standing(
        temperature, pressure, api_gravity, gas_specific_gravity, solution_gor_initial
    )
    assert B_o_Standing == B_o_real


def test_oil_compressibility_Standing(oil_properties):
    """Test Standing's oil compressibility (all saturations)."""
    (
        temperature,
        pressure,
        api_gravity,
        gas_specific_gravity,
        solution_gor_initial,
        fluid,
    ) = oil_properties
    pseudocritical_temperature = -102.21827232417752
    pseudocritical_pressure = 653.258206420053
    if fluid == "black oil" and math.fabs(pressure - 3000) < 1:
        C_o_real = pytest.approx(9.172308e-06, rel=1e-3)
    elif fluid == "black oil" and math.fabs(pressure - 2000) < 1:
        C_o_real = pytest.approx(2.11633e-4, rel=1e-3)
    else:
        raise NotImplementedError
    C_o_Standing = oil.oil_compressibility_Standing(
        temperature,
        pressure,
        api_gravity,
        gas_specific_gravity,
        solution_gor_initial,
        pseudocritical_temperature,
        pseudocritical_pressure,
    )
    assert C_o_Standing == C_o_real


def test_oil_density_Standing(oil_properties):
    """Test Standing's density (depends on solution GOR, b_o)."""
    (
        temperature,
        pressure,
        api_gravity,
        gas_specific_gravity,
        solution_gor_initial,
        fluid,
    ) = oil_properties
    if fluid == "black oil" and math.fabs(pressure - 3000) < 1:
        density_real = pytest.approx(43.50215, rel=1e-3)
    elif fluid == "black oil" and math.fabs(pressure - 2000) < 1:
        density_real = pytest.approx(45, rel=0.2)  # for now until it works
    else:
        raise NotImplementedError

    density_Standing = oil.density_Standing(
        temperature, pressure, api_gravity, gas_specific_gravity, solution_gor_initial
    )
    assert density_Standing == density_real


def test_viscosity_beggs_robinson(oil_properties):
    """Test Beggs-Robinson viscosity (depends on solution GOR, bubble point)."""
    (
        temperature,
        pressure,
        api_gravity,
        gas_specific_gravity,
        solution_gor_initial,
        fluid,
    ) = oil_properties
    if fluid == "black oil" and math.fabs(pressure - 3000) < 1:
        viscosity_real = pytest.approx(0.5113674, rel=1e-3)
    elif fluid == "black oil" and math.fabs(pressure - 2000) < 1:
        viscosity_real = pytest.approx(0.5811379, rel=1e-3)
    else:
        raise ValueError("pressure tests only cover 3000 and 2000")
    viscosity_br = oil.viscosity_beggs_robinson(
        temperature, pressure, api_gravity, gas_specific_gravity, solution_gor_initial
    )
    assert viscosity_br == viscosity_real

==> bluebonnet-0.2.1.tar.gz: bluebonnet-0.2.1/tests/fluids/test_oil.py <==
"""Define a suite a tests for the oil module."""
from __future__ import annotations

import math

import pytest
from bluebonnet.fluids import oil

TEMPERATURE_STANDARD = 60.0
PRESSURE_STANDARD = 14.70


def test_bubblepoint_pressure_Standing(oil_properties):
    """Test Standing bubblepoint pressure calculation."""
    (
        temperature,
        pressure,
        api_gravity,
        gas_specific_gravity,
        solution_gor_initial,
        fluid,
    ) = oil_properties
    pressure_bubblepoint_real = pytest.approx(2603.1217021875277)
    pressure_bubblepoint = oil.pressure_bubblepoint_Standing(
        temperature, api_gravity, gas_specific_gravity, solution_gor_initial
    )
    assert pressure_bubblepoint == pressure_bubblepoint_real


def test_solution_gor_Standing(oil_properties):
    """Test Standing calculation of solution gas:oil raio."""
    (
        temperature,
        pressure,
        api_gravity,
        gas_specific_gravity,
        solution_gor_initial,
        fluid,
    ) = oil_properties
    if fluid == "black oil" and math.fabs(pressure - 3000) < 1:
        gor_real = pytest.approx(650)
    elif fluid == "black oil" and math.fabs(pressure - 2000) < 1:
        gor_real = pytest.approx(474.8228813376839)
    else:
        raise NotImplementedError
    gor_standing = oil.solution_gor_Standing(
        temperature, pressure, api_gravity, gas_specific_gravity, solution_gor_initial
    )
    assert gor_standing == gor_real


def test_dgor_dpressure_Standing(oil_properties):
    """Test whether Standing gets change in GOR over pressure right."""
    (
        temperature,
        pressure,
        api_gravity,
        gas_specific_gravity,
        solution_gor_initial,
        fluid,
    ) = oil_properties
    if fluid == "black oil" and math.fabs(pressure - 3000) < 1:
        dgor_real = pytest.approx(0)
    elif fluid == "black oil" and math.fabs(pressure - 2000) < 1:
        dgor_real = pytest.approx(0.2824395998221715)
    else:
        raise NotImplementedError
    dgor_standing = oil.dgor_dpressure_Standing(
        temperature, pressure, api_gravity, gas_specific_gravity, solution_gor_initial
    )
    assert dgor_standing == dgor_real


def test_B_o_bubblepoint_Standing(oil_properties):
    """Test Standing bubblepoint formation volume factor."""
    (
        temperature,
        pressure,
        api_gravity,
        gas_specific_gravity,
        solution_gor_initial,
        fluid,
    ) = oil_properties
    B_o_bubblepoint_real = pytest.approx(1.3860514623492897)
    B_o_Standing = oil.b_o_bubblepoint_Standing(
        temperature, api_gravity, gas_specific_gravity, solution_gor_initial
    )
    assert B_o_bubblepoint_real == B_o_Standing


def test_oil_compressibility_undersat_Standing(oil_properties):
    """Test Standing oil compressibility for undersaturated oil."""
    (
        temperature,
        pressure,
        api_gravity,
        gas_specific_gravity,
        solution_gor_initial,
        fluid,
    ) = oil_properties

    # overwrite pressure to be above saturation pressure
    pressure = 3000.0
    C_o_real = pytest.approx(1.4719851e-05)
    C_o_Standing = oil.oil_compressibility_undersat_Standing(
        temperature, pressure, api_gravity, gas_specific_gravity, solution_gor_initial
    )
    assert C_o_Standing == C_o_real


def test_oil_compressibility_undersat_Spivey(oil_properties):
    """Test Spivey's oil compressibility for undersaturated oil."""
    (
        temperature,
        pressure,
        api_gravity,
        gas_specific_gravity,
        solution_gor_initial,
        _,
    ) = oil_properties

    # overwrite pressure to be above saturation pressure
    if pressure < 2001.0:
        pytest.skip("only makes sense if undersaturated")
    C_o_real = pytest.approx(9.1723089e-6)
    C_o_Spivey = oil.oil_compressibility_undersat_Spivey(
        temperature, pressure, api_gravity, gas_specific_gravity, solution_gor_initial
    )
    assert C_o_Spivey == C_o_real


def test_B_o_Standing(oil_properties):
    """Test Standing's formation volume factor (all saturations) for oil."""
    (
        temperature,
        pressure,
        api_gravity,
        gas_specific_gravity,
        solution_gor_initial,
        fluid,
    ) = oil_properties
    if fluid == "black oil" and math.fabs(pressure - 3000) < 1:
        B_o_real = pytest.approx(1.38101, rel=1e-3)
    elif fluid == "black oil" and math.fabs(pressure - 2000) < 1:
        B_o_real = pytest.approx(1.2929990, rel=1e-3)
    else:
        raise NotImplementedError
    B_o_Standing = oil.b_o_Standing(
        temperature, pressure, api_gravity, gas_specific_gravity, solution_gor_initial
    )
    assert B_o_Standing == B_o_real


def test_oil_compressibility_Standing(oil_properties):
    """Test Standing's oil compressibility (all saturations)."""
    (
        temperature,
        pressure,
        api_gravity,
        gas_specific_gravity,
        solution_gor_initial,
        fluid,
    ) = oil_properties
    pseudocritical_temperature = -102.21827232417752
    pseudocritical_pressure = 653.258206420053
    if fluid == "black oil" and math.fabs(pressure - 3000) < 1:
        C_o_real = pytest.approx(9.172308e-06, rel=1e-3)
    elif fluid == "black oil" and math.fabs(pressure - 2000) < 1:
        C_o_real = pytest.approx(2.11633e-4, rel=1e-3)
    else:
        raise NotImplementedError
    C_o_Standing = oil.oil_compressibility_Standing(
        temperature,
        pressure,
        api_gravity,
        gas_specific_gravity,
        solution_gor_initial,
        pseudocritical_temperature,
        pseudocritical_pressure,
    )
    assert C_o_Standing == C_o_real


def test_oil_density_Standing(oil_properties):
    """Test Standing's density (depends on solution GOR, b_o)."""
    (
        temperature,
        pressure,
        api_gravity,
        gas_specific_gravity,
        solution_gor_initial,
        fluid,
    ) = oil_properties
    if fluid == "black oil" and math.fabs(pressure - 3000) < 1:
        density_real = pytest.approx(43.50215, rel=1e-3)
    elif fluid == "black oil" and math.fabs(pressure - 2000) < 1:
        density_real = pytest.approx(45, rel=0.2)  # for now until it works
    else:
        raise NotImplementedError

    density_Standing = oil.density_Standing(
        temperature, pressure, api_gravity, gas_specific_gravity, solution_gor_initial
    )
    assert density_Standing == density_real


def test_viscosity_beggs_robinson(oil_properties):
    """Test Beggs-Robinson viscosity (depends on solution GOR, bubble point)."""
    (
        temperature,
        pressure,
        api_gravity,
        gas_specific_gravity,
        solution_gor_initial,
        fluid,
    ) = oil_properties
    if fluid == "black oil" and math.fabs(pressure - 3000) < 1:
        viscosity_real = pytest.approx(0.5113674, rel=1e-3)
    elif fluid == "black oil" and math.fabs(pressure - 2000) < 1:
        viscosity_real = pytest.approx(0.5811379, rel=1e-3)
    else:
        msg = "pressure tests only cover 3000 and 2000"
        raise ValueError(msg)
    viscosity_br = oil.viscosity_beggs_robinson(
        temperature, pressure, api_gravity, gas_specific_gravity, solution_gor_initial
    )
    assert viscosity_br == viscosity_real
